@@ -12,7 +12,7 @@ class Storage(object):
     def release_lock(self, lock):
         raise NotImplementedError()
 
-    def acquire_lock(self, key, expiration=None):
+    def acquire_lock(self, key, timeout=None):
         raise NotImplementedError()
 
     def is_expired(self, key, expiration=None):
